@@ -154,9 +154,14 @@
 #' \item Arcsine transformation (\code{sm = "PAS"})
 #' \item Freeman-Tukey Double arcsine transformation (\code{sm = "PFT"})
 #' \item Log transformation (\code{sm = "PLN"})
-#' \item Raw, i.e. untransformed, proportions (\code{sm = "PRAW"})
+#' \item No transformation (\code{sm = "PRAW"})
 #' }
 #'
+#' List elements \code{TE}, \code{TE.common}, \code{TE.random}, etc.,
+#' contain the transformed proportions. In printouts and plots these
+#' values are back transformed if argument \code{backtransf = TRUE}
+#' (default).
+#'
 #' A generalised linear mixed model (GLMM) - more specific, a random
 #' intercept logistic regression model - can be utilised for the
 #' meta-analysis of proportions (Stijnen et al., 2010). This is the
@@ -328,7 +333,7 @@
 #' An object of class \code{c("metaprop", "meta")} with corresponding
 #' generic functions (see \code{\link{meta-object}}).
 #' 
-#' @author Guido Schwarzer \email{sc@@imbi.uni-freiburg.de}
+#' @author Guido Schwarzer \email{guido.schwarzer@@uniklinik-freiburg.de}
 #' 
 #' @seealso \code{\link{meta-package}}, \code{\link{update.meta}},
 #'   \code{\link{metacont}}, \code{\link{metagen}},
@@ -570,7 +575,7 @@ metaprop <- function(event, n, studlab,
                      random = gs("random") | !is.null(tau.preset),
                      overall = common | random,
                      overall.hetstat = common | random,
-                     prediction = gs("prediction"),
+                     prediction = gs("prediction") | !missing(method.predict),
                      ##
                      method.tau =
                        ifelse(!is.na(charmatch(tolower(method), "glmm",
@@ -644,6 +649,7 @@ metaprop <- function(event, n, studlab,
     method.tau <- if (method == "GLMM") "ML" else gs("method.tau")
   method.tau <- setchar(method.tau, gs("meth4tau"))
   ##
+  missing.tau.common <- missing(tau.common)
   tau.common <- replaceNULL(tau.common, FALSE)
   chklogical(tau.common)
   ##
@@ -659,7 +665,7 @@ metaprop <- function(event, n, studlab,
     setmethodpredict(method.predict, missing.method.predict,
                      method.tau, missing.method.tau)
   ##
-  if (method.predict == "NNF")
+  if (any(method.predict == "NNF"))
     is.installed.package("pimeta", argument = "method.predict", value = "NNF")
   ##
   missing.adhoc.hakn.pi <- missing(adhoc.hakn.pi)
@@ -674,16 +680,17 @@ metaprop <- function(event, n, studlab,
   ##
   chknumeric(pscale, length = 1)
   if (!backtransf & pscale != 1 & !is.untransformed(sm)) {
-    warning("Argument 'pscale' set to 1 as argument 'backtransf' is FALSE.")
+    warning("Argument 'pscale' set to 1 as argument 'backtransf' is FALSE.",
+            call. = FALSE)
     pscale <- 1
   }
   ##
   if (!is.null(text.common))
     chkchar(text.common, length = 1)
   if (!is.null(text.random))
-    chkchar(text.random, length = 1)
+    chkchar(text.random)
   if (!is.null(text.predict))
-    chkchar(text.predict, length = 1)
+    chkchar(text.predict)
   if (!is.null(text.w.common))
     chkchar(text.w.common, length = 1)
   if (!is.null(text.w.random))
@@ -854,11 +861,15 @@ metaprop <- function(event, n, studlab,
   ## Additional checks
   ##
   if (!by & tau.common) {
-    warning("Value for argument 'tau.common' set to FALSE as argument 'subgroup' is missing.")
+    warning("Value for argument 'tau.common' set to FALSE as ",
+            "argument 'subgroup' is missing.",
+            call. = FALSE)
     tau.common <- FALSE
   }
   if (by & !tau.common & !is.null(tau.preset)) {
-    warning("Argument 'tau.common' set to TRUE as argument tau.preset is not NULL.")
+    warning("Argument 'tau.common' set to TRUE as ",
+            "argument tau.preset is not NULL.",
+            call. = FALSE)
     tau.common <- TRUE
   }
   
@@ -1092,13 +1103,13 @@ metaprop <- function(event, n, studlab,
     }
     ##
     else if (sm == "PAS") {
-      lower.study <- asin2p(lower.study, value = "lower", warn = FALSE)
-      upper.study <- asin2p(upper.study, value = "upper", warn = FALSE)
+      lower.study <- asin2p(lower.study, value = "lower")
+      upper.study <- asin2p(upper.study, value = "upper")
     }
     ##
     else if (sm == "PFT") {
-      lower.study <- asin2p(lower.study, n, value = "lower", warn = FALSE)
-      upper.study <- asin2p(upper.study, n, value = "upper", warn = FALSE)
+      lower.study <- asin2p(lower.study, n, value = "lower")
+      upper.study <- asin2p(upper.study, n, value = "upper")
     }
     ##
     else if (sm == "PLN") {
@@ -1139,14 +1150,15 @@ metaprop <- function(event, n, studlab,
     }
     ##
     if (!(method.tau %in% c("REML", "ML"))) {
-      if (!missing(method.tau))
-        warning("For three-level model, argument 'method.tau' set to \"REML\".",
+      if (!missing.method.tau)
+        warning("For three-level model, argument 'method.tau' set to ",
+                "\"REML\".",
                 call. = FALSE)
       method.tau <- "REML"
     }
     ##
     if (by & !tau.common) {
-      if (!missing(tau.common))
+      if (!missing.tau.common)
         warning("For three-level model, argument 'tau.common' set to ",
                 "\"TRUE\".",
                 call. = FALSE)
@@ -1160,55 +1172,22 @@ metaprop <- function(event, n, studlab,
   ## (9) Additional checks for GLMM
   ##
   ##
-  if (is.glmm & sm != "PLOGIT")
-    stop("Generalised linear mixed models only possible with ",
-         "argument 'sm = \"PLOGIT\"'.")
-  ##
-  if (is.glmm & method.tau != "ML")
-    stop("Generalised linear mixed models only possible with ",
-         "argument 'method.tau = \"ML\"'.")
-  ##
-  if (is.glmm & method.random.ci == "KR")
-    stop("Kenward-Roger method for random effects meta-analysis not ",
-         "available for GLMMs.",
-         call. = FALSE)
-  ##
-  if (is.glmm & method.predict == "KR")
-    stop("Kenward-Roger method for prediction interval not ",
-         "available for GLMMs.",
-         call. = FALSE)
-  ##
-  if (is.glmm & method.predict == "NNF")
-    stop("Bootstrap method for prediction interval not ",
-         "available for GLMMs.",
-         call. = FALSE)
-  ##
-  if (is.glmm & method.random.ci == "HK" & adhoc.hakn.ci != "") {
-    if (!missing.adhoc.hakn.ci)
-      warning("Ad hoc correction for Hartung-Knapp method not ",
-              "available for GLMMs.",
-              call. = FALSE)
-    adhoc.hakn.ci <- ""
-  }
-  ##
-  if (is.glmm & method.predict == "HK" & adhoc.hakn.pi != "") {
-    if (!missing.adhoc.hakn.pi)
-      warning("Ad hoc Hartung-Knapp correction ffor prediction interval not ",
-              "available for GLMMs.",
-              call. = FALSE)
-    adhoc.hakn.pi <- ""
-  }
-  ##
   if (is.glmm) {
+    chkglmm(sm, method.tau, method.random.ci, method.predict,
+            adhoc.hakn.ci, adhoc.hakn.pi,
+            "PLOGIT")
+    ##
     if (!is.null(TE.tau)) {
       if (warn)
-        warning("Argument 'TE.tau' not considered for GLMM.")
+        warning("Argument 'TE.tau' not considered for GLMM.",
+                call. = FALSE)
       TE.tau <- NULL
     }
     ##
     if (!is.null(tau.preset)) {
       if (warn)
-        warning("Argument 'tau.preset' not considered for GLMM.")
+        warning("Argument 'tau.preset' not considered for GLMM.",
+                call. = FALSE)
       tau.preset <- NULL
     }
   }
@@ -1221,24 +1200,9 @@ metaprop <- function(event, n, studlab,
   ##
   k <- sum(!is.na(event[!exclude]) & !is.na(n[!exclude]))
   ##
-  if (k == 1 & method.random.ci != "classic")
-    method.random.ci <- "classic"
-  ##
-  if (is.glmm & k > 0) {
-    glmm.common <-
-      runNN(rma.glmm,
-            list(xi = event[!exclude], ni = n[!exclude],
-                 method = "FE",
-                 test = ifelse(method.random.ci == "HK", "t", "z"),
-                 level = 100 * level.ma,
-                 measure = "PLO", control = control,
-                 ...))
-    ##
-    TE.common   <- as.numeric(glmm.common$b)
-    seTE.common <- as.numeric(glmm.common$se)
-    ##
-    w.common <- rep(NA, length(event))
-  }
+  for (i in seq_along(method.random.ci))
+    if (k == 1 & method.random.ci[i] == "HK")
+      method.random.ci[i] <- "classic"
   ##
   m <- metagen(TE, seTE, studlab,
                exclude = if (missing.exclude) NULL else exclude,
@@ -1329,196 +1293,63 @@ metaprop <- function(event, n, studlab,
     m$pval <- rep(NA, length(m$pval))
   }
   ##
+  if (is.glmm | three.level) {
+    m$seTE.hakn.ci <- m$seTE.hakn.adhoc.ci <-
+      m$seTE.hakn.pi <- m$seTE.hakn.adhoc.pi <-
+        m$seTE.kero <- NA
+    ##
+    m$text.random <- gsub("(HK)", "(T)", m$text.random, fixed = TRUE)
+  }
+  ##
   res <- c(res, m)
   res$null.effect <- null.effect
   ##
-  ## Add data
+  ## Run GLMM and add data
   ##
   if (is.glmm & k > 0) {
-    ##
-    ci.f <- ci(TE.common, seTE.common, level = level.ma,
-               null.effect = transf.null.effect)
-    ##
     res$method <- "GLMM"
     ##
-    res$TE.common <- TE.common
-    res$seTE.common <- seTE.common
-    res$w.common <- w.common
-    res$lower.common <- ci.f$lower
-    res$upper.common <- ci.f$upper
-    res$statistic.common <- ci.f$statistic
-    res$pval.common <- ci.f$p
-    res$zval.common <- ci.f$statistic
+    list.prop <- list(xi = event[!exclude], ni = n[!exclude], measure = "PLO")
     ##
-    if (sum(!exclude) > 1 &
-        sum(event[!exclude], na.rm = TRUE) > 0 &
-        any(event[!exclude] != n[!exclude]))
-      glmm.random <-
-        runNN(rma.glmm,
-              list(xi = event[!exclude], ni = n[!exclude],
-                   method = method.tau,
-                   test = ifelse(method.random.ci == "HK", "t", "z"),
-                   level = 100 * level.ma,
-                   measure = "PLO", control = control,
-                   ...))
-    else {
-      ##
-      ## Fallback to common effect model due to small number of studies
-      ## or zero or all events
-      ##
-      glmm.random <- glmm.common
-    }
+    use.random <-
+      sum(!exclude) > 1 &
+      sum(event[!exclude], na.rm = TRUE) > 0 &
+      any(event[!exclude] != n[!exclude])
     ##
-    TE.random   <- as.numeric(glmm.random$b)
-    seTE.random <- as.numeric(glmm.random$se)
+    res.glmm <-
+      runGLMM(list.prop,
+              method.tau = method.tau,
+              method.random.ci = method.random.ci,
+              level = level.ma,
+              control = control, use.random = use.random)
     ##
-    ci.r <- ci(TE.random, seTE.random, level = level.ma,
-               null.effect = transf.null.effect,
-               df = if (method.random.ci == "HK") k - 1)
-    ##
-    res$w.random <- rep(NA, length(event))
-    ##
-    res$TE.random <- TE.random
-    res$seTE.random <- seTE.random
-    res$lower.random <- ci.r$lower
-    res$upper.random <- ci.r$upper
-    res$statistic.random <- ci.r$statistic
-    res$pval.random <- ci.r$p
-    res$zval.random <- ci.r$statistic
-    ##
-    ## Prediction interval
-    ##
-    res$upper.predict <- res$lower.predict <- res$seTE.predict <- NA
-    ##
-    tau2.calc <- if (is.na(glmm.random$tau2)) 0 else glmm.random$tau2
-    seTE.predict <- sqrt(seTE.random^2 + tau2.calc)
-    ##
-    if (method.predict == "HTS" && k >= 3)
-      ci.p <- ci(TE.random, seTE.predict, level.predict, k - 2)
-    else if (method.predict == "S")
-      ci.p <- ci(TE.random, seTE.predict, level.predict)
-    else
-      ci.p <- list(lower = NA, upper = NA)
-    ##
-    res$seTE.predict <- seTE.predict
-    res$lower.predict <- ci.p$lower
-    res$upper.predict <- ci.p$upper
-    ##
-    res$Q <- if (glmm.random$k > 1) glmm.random$QE.Wld else 0
-    res$df.Q <- glmm.random$QE.df
-    res$pval.Q <- pvalQ(res$Q, res$df.Q)
-    ##
-    res$Q.LRT <- if (glmm.random$k > 1) glmm.random$QE.LRT else 0
-    res$df.Q.LRT <- res$df.Q
-    res$pval.Q.LRT <- pvalQ(res$Q.LRT, res$df.Q.LRT)
-    ##
-    if (k > 1) {
-      res$tau <- sqrt(glmm.random$tau2)
-      res$tau2 <- glmm.random$tau2
-      res$se.tau2 <- glmm.random$se.tau2
-    }
-    else
-      res$se.tau2 <- NA
-    ##
-    res$lower.tau2 <- NA
-    res$upper.tau2 <- NA
-    ##
-    res$lower.tau <- NA
-    res$upper.tau <- NA
-    ##
-    res$method.tau.ci <- ""
-    res$sign.lower.tau <- ""
-    res$sign.upper.tau <- ""
-    ##
-    H <- calcH(res$Q, res$df.Q, level.ma)
-    res$H <- H$TE
-    res$lower.H <- H$lower
-    res$upper.H <- H$upper
-    ##
-    I2 <- isquared(res$Q, res$df.Q, level.ma)
-    res$I2 <- I2$TE
-    res$lower.I2 <- I2$lower
-    res$upper.I2 <- I2$upper
-    ##
-    res$Rb <- NA
-    res$lower.Rb <- NA
-    res$upper.Rb <- NA
-    ##
-    res$.glmm.common  <- glmm.common
-    res$.glmm.random <- glmm.random
-    res$version.metafor <- packageDescription("metafor")$Version
+    res <- addGLMM(res, res.glmm)
     ##
     if (by) {
       n.subgroups <- length(unique(subgroup[!exclude]))
       if (n.subgroups > 1)
-        subgroup.glmm <- factor(subgroup[!exclude], bylevs(subgroup[!exclude]))
-      else
-        subgroup.glmm <- NA
+        subgroup.glmm <-
+          factor(subgroup[!exclude], bylevs(subgroup[!exclude]))
       ##
-      glmm.random.by <-
-        try(suppressWarnings(
-          runNN(rma.glmm,
-                list(xi = event[!exclude], ni = n[!exclude],
-                     mods =
-                       if (n.subgroups > 1)
-                         as.call(~ subgroup.glmm) else NULL,
-                     method = method.tau,
-                     test = ifelse(method.random.ci == "HK", "t", "z"),
-                     level = 100 * level.ma,
-                     measure = "PLO", control = control,
-                     data = data.frame(subgroup.glmm),
-                     ...))),
-          silent = TRUE)
-      ##
-      if ("try-error" %in% class(glmm.random.by))
-        if (grepl(paste0("Number of parameters to be estimated is ",
-                         "larger than the number of observations"),
-                  glmm.random.by)) {
-          glmm.random.by <-
-            suppressWarnings(
-              runNN(rma.glmm,
-                    list(xi = event[!exclude], ni = n[!exclude],
-                         mods =
-                           if (n.subgroups > 1)
-                             as.call(~ subgroup.glmm) else NULL,
-                         method = "FE",
-                         test = ifelse(method.random.ci == "HK", "t", "z"),
-                         level = 100 * level.ma,
-                         measure = "PLO", control = control,
-                         data = data.frame(subgroup.glmm),
-                         ...)))
-        }
-        else
-          stop(glmm.random.by)
-      ##
-      Q.r <- glmm.random.by$QE.Wld
-      df.Q.r <- glmm.random.by$k - glmm.random.by$p
-      ##
-      H.r  <- calcH(Q.r, df.Q.r, level.ma)
-      I2.r <- isquared(Q.r, df.Q.r, level.ma)
-      ##
-      hcc <- list(tau2.resid = glmm.random.by$tau2,
-                  lower.tau2.resid = NA,
-                  upper.tau2.resid = NA,
-                  ##
-                  tau.resid = sqrt(glmm.random.by$tau2),
-                  lower.tau.resid = NA,
-                  upper.tau.resid = NA,
-                  sign.lower.tau.resid = "",
-                  sign.upper.tau.resid = "",
-                  ##
-                  Q.resid = Q.r,
-                  df.Q.resid = df.Q.r,
-                  pval.Q.resid = pvalQ(Q.r, df.Q.r),
-                  ##
-                  H.resid = H.r$TE,
-                  lower.H.resid = H.r$lower,
-                  upper.H.resid = H.r$upper,
-                  ##
-                  I2.resid = I2.r$TE,
-                  lower.I2.resid = I2.r$lower,
-                  upper.I2.resid = I2.r$upper
-                  )
+      hcc <-
+        hccGLMM(
+          res,
+          runGLMM(list.prop,
+                  method.tau = method.tau,
+                  method.random.ci = method.random.ci,
+                  level = level.ma,
+                  data =
+                    if (n.subgroups > 1)
+                      list(data = data.frame(subgroup.glmm))
+                    else
+                      NULL,
+                  mods =
+                    if (n.subgroups > 1)
+                      as.call(~ subgroup.glmm)
+                    else
+                      NULL,
+                  control = control, use.random = use.random)$glmm.random[[1]]
+        )
     }
   }
   ##
@@ -1559,8 +1390,9 @@ metaprop <- function(event, n, studlab,
       res <- c(res, subgroup(res, tau.preset))
     else {
       if (is.glmm)
-        res <- c(res, subgroup(res, NULL,
-                               factor(res$subgroup, bylevs(res$subgroup)), ...))
+        res <- c(res,
+                 subgroup(res, NULL,
+                          factor(res$subgroup, bylevs(res$subgroup)), ...))
       else if (res$three.level)
         res <- c(res,
                  subgroup(res, NULL,
@@ -1569,33 +1401,8 @@ metaprop <- function(event, n, studlab,
         res <- c(res, subgroup(res, hcc$tau.resid))
     }
     ##
-    if (tau.common && is.null(tau.preset)) {
-      res$Q.w.random <- hcc$Q.resid
-      res$df.Q.w.random <- hcc$df.Q.resid
-      res$pval.Q.w.random <- hcc$pval.Q.resid
-      ##
-      res$tau2.resid <- hcc$tau2.resid
-      res$lower.tau2.resid <- hcc$lower.tau2.resid
-      res$upper.tau2.resid <- hcc$upper.tau2.resid
-      ##
-      res$tau.resid <- hcc$tau.resid
-      res$lower.tau.resid <- hcc$lower.tau.resid
-      res$upper.tau.resid <- hcc$upper.tau.resid
-      res$sign.lower.tau.resid <- hcc$sign.lower.tau.resid
-      res$sign.upper.tau.resid <- hcc$sign.upper.tau.resid
-      ##
-      res$Q.resid <- hcc$Q.resid
-      res$df.Q.resid <- hcc$df.Q.resid
-      res$pval.Q.resid <- hcc$pval.Q.resid
-      ##
-      res$H.resid <- hcc$H.resid
-      res$lower.H.resid <- hcc$lower.H.resid
-      res$upper.H.resid <- hcc$upper.H.resid
-      ##
-      res$I2.resid <- hcc$I2.resid
-      res$lower.I2.resid <- hcc$lower.I2.resid
-      res$upper.I2.resid <- hcc$upper.I2.resid
-    }
+    if (tau.common && is.null(tau.preset))
+      res <- addHet(res, hcc, !is.glmm)
     ##
     res$n.e.w <- NULL
     res$n.c.w <- NULL
@@ -1605,28 +1412,16 @@ metaprop <- function(event, n, studlab,
     res$time.e.w <- NULL
     res$time.c.w <- NULL
     res$t.harmonic.mean.w <- NULL
+    ##
+    res <- setNAwithin(res, res$three.level | is.glmm)
   }
   ##
   ## Backward compatibility
   ##
-  res$TE.fixed <- res$TE.common
-  res$seTE.fixed <- res$seTE.common
-  res$w.fixed <- res$w.common
-  res$lower.fixed <- res$lower.common
-  res$upper.fixed <- res$upper.common
-  res$statistic.fixed <- res$statistic.common
-  res$pval.fixed <- res$pval.common
-  res$zval.fixed <- res$zval.common
-  ##
-  if (by) {
-    res$byvar <- subgroup
-    res$bylab <- subgroup.name
-    res$print.byvar <- print.subgroup.name
-    res$byseparator <- sep.subgroup
-  }
+  res <- backward(res)
   ##
   class(res) <- c(fun, "meta")
-
+  
   
   res
 }
